@@ -56,7 +56,7 @@
     <name>ConfigPlacement</name>
     <message>
         <location filename="../config/configplacement.ui" line="20"/>
-        <source>Configure placement</source>
+        <source>Configure Placement</source>
         <translation>Configurar l’emplaçament</translation>
     </message>
     <message>
@@ -369,45 +369,45 @@ Colorize icons based on widget style (palette)</source>
 <context>
     <name>LXQtPanel</name>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1325"/>
-        <location filename="../lxqtpanel.cpp" line="1351"/>
+        <location filename="../lxqtpanel.cpp" line="1361"/>
+        <location filename="../lxqtpanel.cpp" line="1387"/>
         <source>Panel</source>
         <translation>Panèl</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1354"/>
+        <location filename="../lxqtpanel.cpp" line="1390"/>
         <source>Configure Panel</source>
         <translation type="unfinished">Configurar lo tablèu de bòrd</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1359"/>
+        <location filename="../lxqtpanel.cpp" line="1395"/>
         <source>Manage Widgets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1365"/>
+        <location filename="../lxqtpanel.cpp" line="1401"/>
         <source>Add New Panel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1372"/>
+        <location filename="../lxqtpanel.cpp" line="1408"/>
         <source>Remove Panel</source>
         <comment>Menu Item</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1377"/>
+        <location filename="../lxqtpanel.cpp" line="1413"/>
         <source>Lock This Panel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1533"/>
+        <location filename="../lxqtpanel.cpp" line="1576"/>
         <source>Remove Panel</source>
         <comment>Dialog Title</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1534"/>
+        <location filename="../lxqtpanel.cpp" line="1577"/>
         <source>Removing a panel can not be undone.
 Do you want to remove this panel?</source>
         <translation type="unfinished"></translation>
@@ -434,12 +434,12 @@ Do you want to remove this panel?</source>
 <context>
     <name>main</name>
     <message>
-        <location filename="../lxqtpanelapplication.cpp" line="95"/>
+        <location filename="../lxqtpanelapplication.cpp" line="340"/>
         <source>Use alternate configuration file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpanelapplication.cpp" line="96"/>
+        <location filename="../lxqtpanelapplication.cpp" line="341"/>
         <source>Configuration file</source>
         <translation type="unfinished"></translation>
     </message>
