@@ -218,22 +218,27 @@
         <translation>העברה למ&amp;טה</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.ui" line="519"/>
+        <location filename="../lxqtworldclockconfiguration.ui" line="518"/>
+        <source>&lt;b&gt;Note:&lt;/b&gt; Middle-click the clock to view the time and date for all configured timezones.</source>
+        <translation>&lt;b&gt;לתשומת ליבך:&lt;/b&gt; לחיצה אמצעית על השעון מציגה את השעון והתאריך לכל אזורי הזמן המוגדרים.</translation>
+    </message>
+    <message>
+        <location filename="../lxqtworldclockconfiguration.ui" line="529"/>
         <source>&amp;General</source>
         <translation>&amp;כללי</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.ui" line="525"/>
+        <location filename="../lxqtworldclockconfiguration.ui" line="535"/>
         <source>Auto&amp;rotate when the panel is vertical</source>
         <translation>להטות אוטומטית כאשר הלוח א&amp;נכי</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.ui" line="535"/>
+        <location filename="../lxqtworldclockconfiguration.ui" line="545"/>
         <source>Show &amp;week numbers in popup calendar</source>
         <translation>הצגת מ&amp;ספרי שבועות בלוח השנה הקופץ</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.ui" line="545"/>
+        <location filename="../lxqtworldclockconfiguration.ui" line="555"/>
         <source>S&amp;how tooltip</source>
         <translation>ה&amp;צגת חלונית עצה</translation>
     </message>
